Module command

Module command 

Structs

ProgressUpdate
Progress update sent from a download command to the engine via channel. This decouples the download task from the RequestGroup RwLock: instead of acquiring group.write().await on every batched progress checkpoint, the download task performs a cheap lock-free send and a single aggregator task applies the update to the RequestGroup.

Enums

CommandStatus

Traits

Command