Module request_group

Module request_group 

Structs

DownloadOptions
GroupId
RequestGroup

Enums

DownloadStatus

Constants

RUNTIME_CHANGEABLE_OPTIONS
Options that can be changed at runtime via aria2.changeOption. All other options are startup-only and cannot be modified after the download begins. Keep in sync with RequestGroup::update_option.