pub struct SeedExitCondition {
pub seed_time: Option<Duration>,
pub seed_ratio: Option<f64>,
}Fields
seed_time: Option<Duration>seed_ratio: Option<f64>Implementations
Sourceimpl SeedExitCondition
impl SeedExitCondition
pub fn infinite() -> Self
pub fn with_time(secs: u64) -> Self
pub fn with_ratio(ratio: f64) -> Self
pub fn with_time_and_ratio(secs: u64, ratio: f64) -> Self
Sourcepub fn check_seed_condition(
uploaded: u64,
downloaded: u64,
seed_ratio: f64,
) -> bool
pub fn check_seed_condition( uploaded: u64, downloaded: u64, seed_ratio: f64, ) -> bool
Check if the seed ratio condition has been met.
Returns true when seeding should stop based on upload/download ratio:
- If
seed_ratio <= 0.0, returnsfalse(infinite seeding) - If
downloaded == 0, returnsfalse(nothing downloaded yet) - Otherwise, checks if
uploaded / downloaded >= seed_ratio
Arguments
uploaded- Total bytes uploaded during this sessiondownloaded- Total bytes downloaded during this sessionseed_ratio- Target ratio (e.g., 1.0 means 1:1 upload:download)
Sourcepub fn check_seed_time(
seeding_started_at: Instant,
seed_time_secs: u64,
is_pure_seeding: bool,
) -> bool
pub fn check_seed_time( seeding_started_at: Instant, seed_time_secs: u64, is_pure_seeding: bool, ) -> bool
Check if the seed time condition has been met.
Returns true when pure seeding duration exceeds the limit:
- If
seed_time_secs == 0, returnsfalse(infinite seeding) - If not in pure seeding phase (
is_pure_seeding == false), returnsfalse - Otherwise, checks if elapsed seconds since
seeding_started_at >= seed_time_secs
Arguments
seeding_started_at- Instant when pure seeding phase beganseed_time_secs- Maximum allowed seeding duration in seconds (0 = infinite)is_pure_seeding- Whether all pieces are complete (true = in seeding phase)