Structs
- Progress
Update - Progress update sent from a download command to the engine via channel.
This decouples the download task from the RequestGroup RwLock: instead of
acquiring
group.write().awaiton every batched progress checkpoint, the download task performs a cheap lock-freesendand a single aggregator task applies the update to theRequestGroup.