pub struct DownloadCommand { /* private fields */ }Implementations
Sourceimpl DownloadCommand
impl DownloadCommand
Sourcepub fn new(
gid: GroupId,
uri: &str,
options: &DownloadOptions,
output_dir: Option<&str>,
output_name: Option<&str>,
) -> Result<Self>
pub fn new( gid: GroupId, uri: &str, options: &DownloadOptions, output_dir: Option<&str>, output_name: Option<&str>, ) -> Result<Self>
Create a DownloadCommand with a standalone RequestGroup (not registered in RequestGroupMan). Use this for simple CLI/test scenarios where external progress queries are not needed.
Sourcepub fn new_with_group(
group: Arc<RwLock<RequestGroup>>,
uri: &str,
options: &DownloadOptions,
output_dir: Option<&str>,
output_name: Option<&str>,
) -> Result<Self>
pub fn new_with_group( group: Arc<RwLock<RequestGroup>>, uri: &str, options: &DownloadOptions, output_dir: Option<&str>, output_name: Option<&str>, ) -> Result<Self>
Create a DownloadCommand with a shared RequestGroup Arc (registered in RequestGroupMan). Use this for RPC and CLI paths where external progress queries are needed.
Sourcepub fn new_with_client(
gid: GroupId,
uri: &str,
options: &DownloadOptions,
output_dir: Option<&str>,
output_name: Option<&str>,
client: Arc<Client>,
) -> Result<Self>
pub fn new_with_client( gid: GroupId, uri: &str, options: &DownloadOptions, output_dir: Option<&str>, output_name: Option<&str>, client: Arc<Client>, ) -> Result<Self>
Create a DownloadCommand with a custom HTTP client and standalone group.
Sourcepub fn new_with_group_and_client(
group: Arc<RwLock<RequestGroup>>,
uri: &str,
options: &DownloadOptions,
output_dir: Option<&str>,
output_name: Option<&str>,
client: Arc<Client>,
) -> Result<Self>
pub fn new_with_group_and_client( group: Arc<RwLock<RequestGroup>>, uri: &str, options: &DownloadOptions, output_dir: Option<&str>, output_name: Option<&str>, client: Arc<Client>, ) -> Result<Self>
Create a DownloadCommand with a shared group Arc and custom HTTP client.
Sourcepub fn new_with_stat_man(
gid: GroupId,
uri: &str,
options: &DownloadOptions,
output_dir: Option<&str>,
output_name: Option<&str>,
stat_man: Arc<ServerStatMan>,
) -> Result<Self>
pub fn new_with_stat_man( gid: GroupId, uri: &str, options: &DownloadOptions, output_dir: Option<&str>, output_name: Option<&str>, stat_man: Arc<ServerStatMan>, ) -> Result<Self>
Create a DownloadCommand with a shared ServerStatMan.
This allows multiple downloads to share server performance statistics, enabling intelligent mirror selection based on historical data.
Sourcepub fn enable_perf_monitor(&mut self)
pub fn enable_perf_monitor(&mut self)
Enable performance monitoring for this download.
This adds minimal overhead (< 1%) to track throughput, latency, memory, and lock wait times.
Sourcepub fn get_perf_metrics(&self) -> Metrics
pub fn get_perf_metrics(&self) -> Metrics
Get performance metrics snapshot (low-overhead, always available)
Sourcepub fn get_perf_report(&self) -> Option<String>
pub fn get_perf_report(&self) -> Option<String>
Get performance report if monitoring is enabled
Sourcepub fn get_perf_report_json(&self) -> Option<String>
pub fn get_perf_report_json(&self) -> Option<String>
Get performance report in JSON format if monitoring is enabled
pub async fn group(&self) -> RwLockReadGuard<'_, RequestGroup>
pub async fn group_mut(&self) -> RwLockWriteGuard<'_, RequestGroup>
Sourcepub fn no_proxy_matcher(&self) -> Option<&NoProxyMatcher>
pub fn no_proxy_matcher(&self) -> Option<&NoProxyMatcher>
Get the NoProxy matcher for checking if a host should bypass proxy
Sourcepub fn stat_man(&self) -> &Arc<ServerStatMan> ⓘ
pub fn stat_man(&self) -> &Arc<ServerStatMan> ⓘ
Get a reference to the server statistics manager.